Crate brokaw

🗞 Brokaw is an Usenet/NNTP client library

APIs

Brokaw provides two primary APIs:

  1. The NntpClient provides a higher-level that provides a a config based builder and automatic deserialization of responses into different types.
  2. The NntpConnection provides a lower-level abstraction that only provides validation that messages adhere to NNTP’s wire format.

Please check out the git repository examples.

Modules

  • The high-level client and configuration API
  • Error and Result types returned by the Brokaw
  • Low level connection/stream APIs
  • Typed commands, responses, and response codes

Structs

Enums