TextArticle

Struct TextArticle 

pub struct TextArticle { /* private fields */ }
A text Netnews article returned by the ARTICLE command

Unlike BinaryArticle a TextArticleMUST have a UTF-8 body.

The following methods can be used to create a TextArticle from a BinaryArticle:

Implementations

Source

impl TextArticle

pub fn number(&self) -> ArticleNumber

The number of the article relative to the group it was retrieved from

pub fn message_id(&self) -> &str

The message id of the article

pub fn headers(&self) -> &Headers

The headers on the article

pub fn body(&self) -> &[String]

Return the body of the article

pub fn from_binary(b: &BinaryArticle) -> Result<Self>

Create a text article from a

pub fn from_binary_lossy(b: &BinaryArticle) -> Self

Create a text article from a binary one, replacing invalid UTF-8 characters with placeholders

pub fn lines(&self) -> Lines<'_>

An iterator over the lines in the body of the article

Each line will not include the CRLF terminator