pub struct TextArticle { /* private fields */ }Expand description
A text Netnews article returned by the ARTICLE command
Unlike BinaryArticle a TextArticleMUST have a UTF-8 body.
The following methods can be used to create a TextArticle from a BinaryArticle:
from_binaryis fallible as it performs UTF-8 checksfrom_binary_lossyis infallible but will replace non UTF-8 characters with placeholders. Please seeString::from_utf8_lossyfor more info.
Implementations
Sourceimpl TextArticle
impl TextArticle
Sourcepub fn number(&self) -> ArticleNumber
pub fn number(&self) -> ArticleNumber
The number of the article relative to the group it was retrieved from
Sourcepub fn message_id(&self) -> &str
pub fn message_id(&self) -> &str
The message id of the article
Sourcepub fn from_binary(b: &BinaryArticle) -> Result<Self>
pub fn from_binary(b: &BinaryArticle) -> Result<Self>
Create a text article from a
Sourcepub fn from_binary_lossy(b: &BinaryArticle) -> Self
pub fn from_binary_lossy(b: &BinaryArticle) -> Self
Create a text article from a binary one, replacing invalid UTF-8 characters with placeholders